import os

from invoke import Program, Collection
from invoke.config import Config, merge_dicts
from . import tasks
from . import __version__


def strtobool(val) -> bool:
    """Convert a string representation of truth to True or False.

    True values are 'y', 'yes', 't', 'true', 'on', and '1'; false values
    are 'n', 'no', 'f', 'false', 'off', and '0'.  Raises ValueError if
    'val' is anything else.
    """
    if not val:
        return False

    val = val.lower()
    if val in ('y', 'yes', 't', 'true', 'on', '1'):
        return True
    elif val in ('n', 'no', 'f', 'false', 'off', '0'):
        return False
    else:
        raise ValueError("invalid truth value %r" % (val,))


class IvyLinkConfig(Config):
    prefix = 'ivylink'

    @staticmethod
    def global_defaults():
        their_defaults = Config.global_defaults()
        # http://docs.pyinvoke.org/en/latest/concepts/configuration.html#environment-variables
        # feels like a hack that we shouldn't need, but setting the environment value
        # without defining config data here just doesn't work.
        my_defaults = {
            'run': {
                'echo': bool(strtobool(os.environ.get('INVOKE_RUN_ECHO', '0'))),
            },
        }
        return merge_dicts(their_defaults, my_defaults)


program = Program(
    version=__version__,
    config_class=IvyLinkConfig,
    namespace=Collection.from_module(tasks),
)
