from io import BytesIO
from ipaddress import ip_network
from PIL import Image
import pybase64
from sanic.exceptions import InvalidUsage
from sanic.views import HTTPMethodView


class IvyLinkImageView(HTTPMethodView):

    def load_image(self, data):
        """
        Decode image from POST body and return Image object.
        """
        try:

            image = Image.open(BytesIO(pybase64.b64decode(data['image'])))
            if image.format == 'PNG' and image.mode != 'RGBA':
                return image.convert('RGBA')

            return image.convert('RGB')

        except Exception as e:
            raise InvalidUsage(str(e)) from None


class IvyLinkGeoIpView(HTTPMethodView):

    def load_ip_address(self, data):
        """
        Return IP address from request data..
        """
        try:
            ip = data['ip']
        except Exception:
            raise InvalidUsage('Provide an IP address value') from None

        try:
            ip_network(ip)
            return ip
        except ValueError:
            raise InvalidUsage(
                message='Not a valid IPv4 or IPv6 address or network',
                context={'ip': ip},
            )


__all__ = (
    'IvyLinkImageView',
    'IvyLinkGeoIpView',
)
