from sanic import Sanic
from sanic.worker.loader import AppLoader
from functools import partial
from ivylink.web.core.request import IvyLinkRequest
from ivylink.images import BlockImageIndex, BlockHashDatabase
from ivylink.web.images.urls import images_bp
from ivylink.web.geoip.urls import geoip_bp
from ivylink.settings import GEOIP_ASN_DB, GEOIP_CITY_DB, LOGGING
import maxminddb


def create_app():
    """
    Create app via loader, based on docs:
    https://sanic.dev/en/guide/deployment/app-loader.html
    """
    try:

        app = Sanic("ivylink_web", request_class=IvyLinkRequest, log_config=LOGGING)
        app.config.FALLBACK_ERROR_FORMAT = 'json'

        app.blueprint(images_bp)
        app.blueprint(geoip_bp)

        app.ctx.inappropriate_image_db = BlockImageIndex(hash_database=BlockHashDatabase())
        app.ctx.geoip_asn_db = maxminddb.open_database(GEOIP_ASN_DB)
        app.ctx.geoip_city_db = maxminddb.open_database(GEOIP_CITY_DB)

        return app

    except Exception as e:
        print(e)
        raise SystemExit()


def serve():

    loader = AppLoader(factory=partial(create_app))
    ivy = loader.load()

    ivy.prepare(host="127.0.0.1", port=10009, dev=False, workers=2)
    Sanic.serve(primary=ivy, app_loader=loader)


if __name__ == '__main__':

    serve()
